package Kirjalista;

import java.util.ArrayList;

import tietorakenne.LinkattuLista;

/**
 * Genren ja kirjan välinen relaatio
 * - pitää kirjaa liimatuista genreistä ja kirjoista
 * - palauttaa kirjojen id:t genren id:n perusteella
 * - palauttaa genrejen id:t kirjan id:n perusteella
 * - lukee ja kirjoittaa tiedostoon
 */
public class GenreRelaatio {
    private LinkattuLista<KirjanGenre> alkiot = new LinkattuLista<KirjanGenre>();
    
    /**
     * Lisää listaan alkion
     * @param alkio Alkio, joka lisätään listaan
     */
    public void lisaa(KirjanGenre alkio) {
        alkiot.lisaa(alkio);
    }
    
    
    /**
     * Palauttaa ArrayListin kirjojen id:istä, joilla on tietty genreid
     * esim. palauttaa kaikkien kirjojen id:t, joiden genre on fantasia
     * @param genreId Genren id, jonka perusteella haetaan kirjojen id:itä
     * @return Kaikkien niiden kirjojen id:t, joiden genren id on genreId 
     */
    public ArrayList<Integer> haeKirjat(int genreId) {
        ArrayList<Integer> kirjojenIdt = new ArrayList<Integer>();
        for (int i = 0; i < alkiot.length(); i++) {
            KirjanGenre alkio = alkiot.getByIndex(i);
            if (alkio.getGenreId() == genreId) {
                kirjojenIdt.add(alkio.getKirjaId());
            }
        }
        return kirjojenIdt;
    }
    
    
    /**
     * Palauttaa ArrayListin genrejen id:istä, joilla on tietty kirjaid
     * eli toisin sanoen palauttaa tietyn kirjan kaikkien genrejen id:t
     * @param kirjaId Kirjan id, jonka perusteella haetaan genrejen id:itä
     * @return Kaikkien niiden genrejen id:t, joiden kirjan id on kirjaId 
     */
    public ArrayList<Integer> haeGenret(int kirjaId) {
        ArrayList<Integer> genrejenIdt = new ArrayList<Integer>();
        for (int i = 0; i < alkiot.length(); i++) {
            KirjanGenre alkio = alkiot.getByIndex(i);
            if (alkio.getKirjaId() == kirjaId) {
                genrejenIdt.add(alkio.getGenreId());
            }
        }
        return genrejenIdt;
    }
    
    
    /**
     * Poistaa alkion annetussa indeksipaikassa
     * @param indeksi Indeksipaikka, josta alkio poistetaan
     */
    public void poista(int indeksi) {
        alkiot.poista(indeksi);
    }
}
